<?php

namespace Drupal\Tests\whitelabel\Functional;

use Drupal\file\Entity\File;
use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\TestFileCreationTrait;
use Drupal\Tests\whitelabel\Traits\WhiteLabelCreationTrait;

/**
 * The base class for white label functional tests.
 *
 * Creates some sensible defaults.
 *
 * @package Drupal\Tests\whitelabel\Functional
 */
abstract class WhiteLabelTestBase extends BrowserTestBase {

  use WhiteLabelCreationTrait {
    createWhiteLabel as drupalCreateWhiteLabel;
  }

  use TestFileCreationTrait {
    getTestFiles as drupalGetTestFiles;
  }

  /**
   * {@inheritdoc}
   */
  public static $modules = [
    'whitelabel',
    'user',
    'image',
  ];

  /**
   * Holds the white label owner.
   *
   * @var \Drupal\user\Entity\User
   */
  public $whiteLabelOwner;

  /**
   * Holds the white label.
   *
   * @var \Drupal\whitelabel\WhiteLabelInterface
   */
  public $whiteLabel;

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    $this->whiteLabelOwner = $this->drupalCreateUser(['serve white label pages']);
    $this->drupalLogin($this->whiteLabelOwner);

    $image_files = $this->drupalGetTestFiles('image');

    $this->whiteLabel = $this->drupalCreateWhiteLabel([
      'token' => 'token1',
      'uid' => $this->whiteLabelOwner->id(),
      'name' => 'White label 1 name',
      'slogan' => 'This module rocks!',
      'logo' => File::create((array) current($image_files)),
    ]);
  }

  /**
   * Function for determining if text is in the system branding block.
   *
   * @param string $text
   *   The text to look for.
   */
  public function inBrandingBlock($text) {
    $this->assertSession()->elementTextContains('css', '.block-system-branding-block', $text);
  }

  /**
   * Function for determining if text is not in the system branding block.
   *
   * @param string $text
   *   The text to look for.
   */
  public function notInBrandingBlock($text) {
    $this->assertSession()->elementTextNotContains('css', '.block-system-branding-block', $text);
  }

  /**
   * Function for determining if the given value is in the src attribute.
   *
   * @param string $src
   *   The value that should be present in the src attribute.
   */
  public function inImagePath($src) {
    $this->assertSession()->elementAttributeContains('css', '.block-system-branding-block img', 'src', $src);
  }

  /**
   * Function for determining if the given value is not in the src attribute.
   *
   * @param string $src
   *   The value that should not be present in the src attribute.
   */
  public function notInImagePath($src) {
    $this->assertSession()->elementAttributeNotContains('css', '.block-system-branding-block img', 'src', $src);
  }

}
